==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { OwnedPoint } from "./OwnedPoint";
import { PathGeometry } from "igniteui-angular-core";
import { Numeric } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterSplineSeries = /*@__PURE__*/ (() => {
    class ScatterSplineSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSplineSeries.$;
            this.v0 = new ScatterFrame();
            this.v2 = new ScatterFrame();
            this.vy = new ScatterFrame();
        }
        get_fd() {
            return true;
        }
        cg() {
            return new ScatterSplineSeriesView(this);
        }
        wp() {
            return true;
        }
        ip() {
            if (!isNaN_(this.io)) {
                return super.ip();
            }
            return Defaults.x;
        }
        o8(a, b, c, d) {
            super.o8(a, b, c, d);
            switch (b) {
                case ScatterSplineSeries.$$p[0]:
                    this.pp(false);
                    this.ol();
                    break;
            }
        }
        bx() {
            if (this.by == 0) {
                return 2;
            }
            else {
                return super.bx();
            }
        }
        x6(a, b) {
            super.x6(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.hj * this.hj;
            let g = Math.min(this.wa != null ? this.wa.count : 0, this.wb != null ? this.wb.count : 0);
            let h = new ScalerParams(0, c, d, this.vu.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.vu.e, e);
                $ret.b = this.h2();
                return $ret;
            })());
            let j = (k) => this.vu.a.ej(this.wa.item(k), h);
            let k = (l) => this.vu.b.ej(this.wb.item(l), i);
            let l = ((() => {
                let $ret = new Clipper(0, d, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let m = 0; m < g;) {
                let n = m;
                ++m;
                while (m < g && this.ze(j, k, n, m) < f) {
                    ++m;
                }
                if (g > this.w1) {
                    l.j(this.zi(j, k, n, m - 1));
                }
                else {
                    let o = new OwnedPoint();
                    o.c = { $type: Point_$type, x: j(n), y: k(n) };
                    o.a = this.c6.item(n);
                    if (!a.u.containsKey(o.a)) {
                        a.u.addItem(o.a, o);
                    }
                }
            }
            if (g > this.w1) {
                l.i = null;
            }
        }
        zi(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a(c), y: b(c) };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a(h);
                f += b(h);
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        ze(a, b, c, d) {
            let e = a(d) - a(c);
            let f = b(d) - b(c);
            return e * e + f * f;
        }
        get_wj() {
            return true;
        }
        nj(a, b) {
            super.nj(a, b);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            c.c7(false);
        }
        yh(a, b) {
            this.nj(false, b);
            super.yh(a, b);
            this.x9(a);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            let d = c.dj;
            this.v7.az(this, this.wo(), runOn(this, this.vi));
            let e = false;
            let f = this.v7.b;
            if (f != null) {
                e = true;
            }
            if (e) {
                this.x2(-1, this.wa.count, b.q);
            }
            this.v7.ad(d, true, false, true, false);
            c.dj.an = new PathGeometry();
            c.dj.an.c = Numeric.h(a.m.count, (g) => a.m._inner[g].x, (g) => a.m._inner[g].y, this.zf);
        }
    }
    ScatterSplineSeries.$t = markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:zf:zh', [1, 0.5]]);
    return ScatterSplineSeries;
})();

==> igniteui-angular-charts-18.2.0-beta.0.tgz: package/esm2015/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-angular-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScalerParams } from "./ScalerParams";
import { PathGeometry } from "igniteui-angular-core";
import { Numeric } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterSplineSeries = /*@__PURE__*/ (() => {
    class ScatterSplineSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSplineSeries.$;
            this.y0 = new ScatterFrame();
            this.y2 = new ScatterFrame();
            this.yy = new ScatterFrame();
        }
        bj() {
            return new ScatterSplineSeries();
        }
        get_f0() {
            return true;
        }
        cs() {
            return new ScatterSplineSeriesView(this);
        }
        zu() {
            return true;
        }
        jk() {
            if (!isNaN_(this.jj)) {
                return super.jk();
            }
            return Defaults.x;
        }
        q7(a, b, c, d) {
            super.q7(a, b, c, d);
            switch (b) {
                case ScatterSplineSeries.$$p[0]:
                    this.rp(false);
                    this.qj();
                    break;
            }
        }
        b2() {
            if (this.b3 == 0) {
                return 2;
            }
            else {
                return super.b2();
            }
        }
        abd(a, b) {
            super.abd(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.by;
            let d = b.bx;
            let e = this.getEffectiveViewport1(b);
            let f = this.id * this.id;
            let g = Math.min(this.zf != null ? this.zf.count : 0, this.zg != null ? this.zg.count : 0);
            let h = new ScalerParams(0, c, d, this.yu.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.yu.e, e);
                $ret.b = this.iy();
                return $ret;
            })());
            let j = (k) => this.yu.a.el(this.zf.item(k), h);
            let k = (l) => this.yu.b.el(this.zg.item(l), i);
            let l = ((() => {
                let $ret = new Clipper(0, d, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let m = 0; m < g;) {
                let n = m;
                ++m;
                while (m < g && this.acl(j, k, n, m) < f) {
                    ++m;
                }
                if (g > this.z7) {
                    l.j(this.acp(j, k, n, m - 1));
                }
                else {
                    let o = new OwnedPoint();
                    o.c = { $type: Point_$type, x: j(n), y: k(n) };
                    o.a = this.dn.item(n);
                    if (!a.u.containsKey(o.a)) {
                        a.u.addItem(o.a, o);
                    }
                }
            }
            if (g > this.z7) {
                l.i = null;
            }
        }
        acp(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a(c), y: b(c) };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a(h);
                f += b(h);
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        acl(a, b, c, d) {
            let e = a(d) - a(c);
            let f = b(d) - b(c);
            return e * e + f * f;
        }
        get_zo() {
            return true;
        }
        o5(a, b) {
            super.o5(a, b);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            c.c9(false);
        }
        abo(a, b) {
            this.o5(false, b);
            super.abo(a, b);
            this.abg(a);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            let d = c.dl;
            this.y7.az(this, this.zt(), runOn(this, this.yn));
            let e = false;
            let f = this.y7.b;
            if (f != null) {
                e = true;
            }
            if (e) {
                this.aa9(-1, this.zf.count, b.q);
            }
            this.y7.ad(d, true, false, true, false);
            c.dl.an = new PathGeometry();
            c.dl.an.c = Numeric.h(a.m.count, (g) => a.m._inner[g].x, (g) => a.m._inner[g].y, this.acm);
        }
    }
    ScatterSplineSeries.$t = markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:acm:aco', [1, 0.5]]);
    return ScatterSplineSeries;
})();
